###############################################################################
######################## initial coding and exclusion #########################
###############################################################################

# NOTE: there is no need to run this on the replication data
# ("Presidential_Vote_Choice-rep.csv"). This code has already
# been run on the replication data.

rm(list=ls())
dat <- read.csv("Presidential_Vote_Choice-mod.csv")

# exclude 4 people who "didn't know" whether they were eligible voters
# and one person who said they were 12 years old and an eligible voter
table(dat$Q0)
dat.o <- dat
dat <- subset(dat.o, subset=(Q0==1))
sel <- ifelse(is.na(dat$Q2!=12), TRUE, dat$Q2!=12)
dat <- dat[sel,]
table(dat$Q0)

dat$treat.f <- as.numeric( factor(dat$block, levels = c("Control", "T1D", "T1R", "T2D", "T2R") ) )

table(dat$treat.f, dat$block)

dat$vote <- rep(NA, dim(dat)[1])
dat$vote[which( is.na(dat$QC.9)==F )] <- dat$QC.9[which( is.na(dat$QC.9)==F )]
dat$vote[which( is.na(dat$QT1.R.9)==F )] <- dat$QT1.R.9[which( is.na(dat$QT1.R.9)==F )]
dat$vote[which( is.na(dat$QT1.D.9)==F )] <- dat$QT1.D.9[which( is.na(dat$QT1.D.9)==F )]
dat$vote[which( is.na(dat$QT2.R.9)==F )] <- dat$QT2.R.9[which( is.na(dat$QT2.R.9)==F )]
dat$vote[which( is.na(dat$QT2.D.9)==F )] <- dat$QT2.D.9[which( is.na(dat$QT2.D.9)==F )]

# one person didn't vote
sum(is.na(dat$vote))

dat$r.vote <- ifelse(dat$vote==1, 1, 0)
dat$d.vote <- ifelse(dat$vote==2, 1, 0)

dat$partyID <- dat$Q5
dat$educ <- dat$Q4
# reclassify those without race as missing
dat$Q3[dat$Q3==""] <- NA
# edit: classify multiracial respondents into all groups
levels(dat$Q3)
dat$black <- ifelse(dat$Q3 == "2" | dat$Q3 == "1,2" | dat$Q3 == "2,4", 1, 0)
dat$native <- ifelse(dat$Q3 == "3" | dat$Q3 == "1,3", 1, 0)
dat$asian <- ifelse(dat$Q3 == "4" | dat$Q3 == "1,4" | dat$Q3 == "2,4", 1, 0)
dat$pacis <- ifelse(dat$Q3 == "5", 1, 0)
dat$other <- ifelse(dat$Q3 == "6" | dat$Q3 == "1,6", 1, 0)
dat$age <- dat$Q2
dat$female <- ifelse(dat$Q1 == 2, 1, 0)

# unrealistic ages were entered
o <- order(dat$age)
dat$age[o]
# change dates into ages
dat$age <- ifelse(dat$age>100, 2017-dat$age, dat$age)
# remove ages listed as two years old (probable miscodes)
dat$age <- ifelse(dat$age<18, NA, dat$age)
dat$age

write.csv(dat, file="Presidential_Vote_Choice-rep.csv")


###############################################################################
######################## Analysis Code ########################################
###############################################################################


###############
# basic graphs 
###############

rm(list=ls())
dat <- read.csv("Presidential_Vote_Choice-rep.csv")

set.seed(123456)

library(ggplot2)
library(stargazer)

### percent support for republican in all treatments
# one-sample t-tests
t.test(subset(dat, subset=(treat.f==1))$r.vote)
t.test(subset(dat, subset=(treat.f==2))$r.vote)
t.test(subset(dat, subset=(treat.f==3))$r.vote)
t.test(subset(dat, subset=(treat.f==4))$r.vote)
t.test(subset(dat, subset=(treat.f==5))$r.vote)

# plots of raw treatment outcomes, % republican support
# with CIs
ci.lims <- matrix(data=NA, nrow=5, ncol=2) 
dat.1 <- subset(dat, subset=(treat.f==1 ) )
ci.lims[1,] <- prop.test( as.table(rev( table(as.numeric(dat.1$treat.f), dat.1$r.vote) )) )$conf.int[1:2]
dat.2 <- subset(dat, subset=(treat.f==2 ) )
ci.lims[2,] <- prop.test( as.table(rev( table(as.numeric(dat.2$treat.f), dat.2$r.vote) )) )$conf.int[1:2]
dat.3 <- subset(dat, subset=(treat.f==3 ) )
ci.lims[3,] <- prop.test( as.table(rev( table(as.numeric(dat.3$treat.f), dat.3$r.vote) )) )$conf.int[1:2]
dat.4 <- subset(dat, subset=(treat.f==4 ) )
ci.lims[4,] <- prop.test( as.table(rev( table(as.numeric(dat.4$treat.f), dat.4$r.vote) )) )$conf.int[1:2]
dat.5 <- subset(dat, subset=(treat.f==5 ) )
ci.lims[5,] <- prop.test( as.table(rev( table(as.numeric(dat.5$treat.f), dat.5$r.vote) )) )$conf.int[1:2]

dat.na <- na.omit( subset(dat, select=c("r.vote", "d.vote", "treat.f")) )
pct1 <- sum(dat.na$r.vote[which(dat.na$treat.f=="1")]) / length(dat.na$r.vote[which(dat.na$treat.f=="1")])
pct2 <- sum(dat.na$r.vote[which(dat.na$treat.f=="2")])/ length(dat.na$r.vote[which(dat.na$treat.f=="2")])
pct3 <- sum(dat.na$r.vote[which(dat.na$treat.f=="3")])/ length(dat.na$r.vote[which(dat.na$treat.f=="3")])
pct4 <- sum(dat.na$r.vote[which(dat.na$treat.f=="4")])/ length(dat.na$r.vote[which(dat.na$treat.f=="4")])
pct5 <- sum(dat.na$r.vote[which(dat.na$treat.f=="5")])/ length(dat.na$r.vote[which(dat.na$treat.f=="5")])

df <- data.frame(Support=rbind(pct1, pct2, pct3, pct4, pct5), Treatment=factor(c(1,2,3,4,5), labels=( c("Control", "Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate") ) ), ci.lo = ci.lims[,1], ci.hi = ci.lims[,2])

ggplot(data=df, aes(x=Treatment, y=Support, ymin=ci.lo, ymax=ci.hi)) + geom_pointrange() + theme_bw() + ylab("% Support for Republican Candidate") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-support.pdf", units="in", width=5, height=5.5)


### percent support for democrat in all treatments
# one-sample t-tests
t.test(subset(dat, subset=(treat.f==1))$d.vote)
t.test(subset(dat, subset=(treat.f==2))$d.vote)
t.test(subset(dat, subset=(treat.f==3))$d.vote)
t.test(subset(dat, subset=(treat.f==4))$d.vote)
t.test(subset(dat, subset=(treat.f==5))$d.vote)

# plots of raw treatment outcomes, % democratic support
# with CIs
ci.lims <- matrix(data=NA, nrow=5, ncol=2) 
dat.1 <- subset(dat, subset=(treat.f==1 ) )
ci.lims[1,] <- prop.test( as.table(rev( table(as.numeric(dat.1$treat.f), dat.1$d.vote) )) )$conf.int[1:2]
dat.2 <- subset(dat, subset=(treat.f==2 ) )
ci.lims[2,] <- prop.test( as.table(rev( table(as.numeric(dat.2$treat.f), dat.2$d.vote) )) )$conf.int[1:2]
dat.3 <- subset(dat, subset=(treat.f==3 ) )
ci.lims[3,] <- prop.test( as.table(rev( table(as.numeric(dat.3$treat.f), dat.3$d.vote) )) )$conf.int[1:2]
dat.4 <- subset(dat, subset=(treat.f==4 ) )
ci.lims[4,] <- prop.test( as.table(rev( table(as.numeric(dat.4$treat.f), dat.4$d.vote) )) )$conf.int[1:2]
dat.5 <- subset(dat, subset=(treat.f==5 ) )
ci.lims[5,] <- prop.test( as.table(rev( table(as.numeric(dat.5$treat.f), dat.5$d.vote) )) )$conf.int[1:2]

dat.na <- na.omit( subset(dat, select=c("r.vote", "d.vote", "treat.f")) )
pct1 <- sum(dat.na$d.vote[which(dat.na$treat.f=="1")]) / length(dat.na$d.vote[which(dat.na$treat.f=="1")])
pct2 <- sum(dat.na$d.vote[which(dat.na$treat.f=="2")])/ length(dat.na$d.vote[which(dat.na$treat.f=="2")])
pct3 <- sum(dat.na$d.vote[which(dat.na$treat.f=="3")])/ length(dat.na$d.vote[which(dat.na$treat.f=="3")])
pct4 <- sum(dat.na$d.vote[which(dat.na$treat.f=="4")])/ length(dat.na$d.vote[which(dat.na$treat.f=="4")])
pct5 <- sum(dat.na$d.vote[which(dat.na$treat.f=="5")])/ length(dat.na$d.vote[which(dat.na$treat.f=="5")])

df <- data.frame(Support=rbind(pct1, pct2, pct3, pct4, pct5), Treatment=factor(c(1,2,3,4,5), labels=( c("Control", "Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate") ) ), ci.lo = ci.lims[,1], ci.hi = ci.lims[,2])

ggplot(data=df, aes(x=Treatment, y=Support, ymin=ci.lo, ymax=ci.hi)) + geom_pointrange() + theme_bw() + ylab("% Support for Democratic Candidate") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-support.pdf", units="in", width=5, height=5.5)


### difference in republican support across treatments (relative to control)
# one-sample t-tests
t.test(r.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==2)))
t.test(r.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==3)))
t.test(r.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==4)))
t.test(r.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==5)))

# plots of raw treatment outcomes, % republican support
# with CIs
ci.lims <- matrix(data=NA, nrow=4, ncol=2) 

dat.1 <- subset(dat, subset=(treat.f==1 | treat.f==2 ) )
dat.1$r.vote[which(dat.1$r.vote==0)] <- 2
ci.lims[1,] <- prop.test( table(as.numeric(dat.1$treat.f), dat.1$r.vote) )$conf.int[1:2]
dat.2 <- subset(dat, subset=(treat.f==1 | treat.f==3 ) )
dat.2$r.vote[which(dat.2$r.vote==0)] <- 2
ci.lims[2,] <- prop.test( table(as.numeric(dat.2$treat.f), dat.2$r.vote) )$conf.int[1:2]
dat.3 <- subset(dat, subset=(treat.f==1 | treat.f==4 ) )
dat.3$r.vote[which(dat.3$r.vote==0)] <- 2
ci.lims[3,] <- prop.test( table(as.numeric(dat.3$treat.f), dat.3$r.vote) )$conf.int[1:2]
dat.4 <- subset(dat, subset=(treat.f==1 | treat.f==5 ) )
dat.4$r.vote[which(dat.4$r.vote==0)] <- 2
ci.lims[4,] <- prop.test( table(as.numeric(dat.4$treat.f), dat.4$r.vote) )$conf.int[1:2]

ci.lims <- ci.lims*(-1)

dat.na <- na.omit( subset(dat, select=c("r.vote", "d.vote", "treat.f")) )
pct1 <- sum(dat.na$r.vote[which(dat.na$treat.f=="2")])/length(dat.na$r.vote[which(dat.na$treat.f=="2")]) - sum(dat.na$r.vote[which(dat.na$treat.f=="1")])/length(dat.na$r.vote[which(dat.na$treat.f=="1")])
pct2 <- sum(dat.na$r.vote[which(dat.na$treat.f=="3")])/length(dat.na$r.vote[which(dat.na$treat.f=="3")]) - sum(dat.na$r.vote[which(dat.na$treat.f=="1")])/length(dat.na$r.vote[which(dat.na$treat.f=="1")])
pct3 <- sum(dat.na$r.vote[which(dat.na$treat.f=="4")])/length(dat.na$r.vote[which(dat.na$treat.f=="4")]) - sum(dat.na$r.vote[which(dat.na$treat.f=="1")])/length(dat.na$r.vote[which(dat.na$treat.f=="1")])
pct4 <- sum(dat.na$r.vote[which(dat.na$treat.f=="5")])/length(dat.na$r.vote[which(dat.na$treat.f=="5")]) - sum(dat.na$r.vote[which(dat.na$treat.f=="1")])/length(dat.na$r.vote[which(dat.na$treat.f=="1")])

df <- data.frame(Support=rbind(pct1, pct2, pct3, pct4), Treatment=factor(c(2,3,4,5), labels=( c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate") ) ), ci.lo = ci.lims[,2], ci.hi = ci.lims[,1])

ggplot(data=df, aes(x=Treatment, y=Support, ymin=ci.lo, ymax=ci.hi)) + geom_pointrange() + theme_bw() + ylab("Difference in % Support for Republican vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-difference-support.pdf", units="in", width=5, height=5.5)


### difference in democratic support across treatments (relative to control)
# one-sample t-tests
t.test(d.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==2)))
t.test(d.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==3)))
t.test(d.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==4)))
t.test(d.vote~treat.f, data = subset(dat, subset=(treat.f==1 | treat.f==5)))

# plots of raw treatment outcomes, % democratic support
# with CIs
ci.lims <- matrix(data=NA, nrow=4, ncol=2) 

dat.1 <- subset(dat, subset=(treat.f==1 | treat.f==2 ) )
dat.1$d.vote[which(dat.1$d.vote==0)] <- 2
ci.lims[1,] <- prop.test( table(as.numeric(dat.1$treat.f), dat.1$d.vote) )$conf.int[1:2]
dat.2 <- subset(dat, subset=(treat.f==1 | treat.f==3 ) )
dat.2$d.vote[which(dat.2$d.vote==0)] <- 2
ci.lims[2,] <- prop.test( table(as.numeric(dat.2$treat.f), dat.2$d.vote) )$conf.int[1:2]
dat.3 <- subset(dat, subset=(treat.f==1 | treat.f==4 ) )
dat.3$d.vote[which(dat.3$d.vote==0)] <- 2
ci.lims[3,] <- prop.test( table(as.numeric(dat.3$treat.f), dat.3$d.vote) )$conf.int[1:2]
dat.4 <- subset(dat, subset=(treat.f==1 | treat.f==5 ) )
dat.4$d.vote[which(dat.4$d.vote==0)] <- 2
ci.lims[4,] <- prop.test( table(as.numeric(dat.4$treat.f), dat.4$d.vote) )$conf.int[1:2]

ci.lims <- ci.lims*(-1)

dat.na <- na.omit( subset(dat, select=c("r.vote", "d.vote", "treat.f")) )
pct1 <- sum(dat.na$d.vote[which(dat.na$treat.f=="2")])/length(dat.na$d.vote[which(dat.na$treat.f=="2")]) - sum(dat.na$d.vote[which(dat.na$treat.f=="1")])/length(dat.na$d.vote[which(dat.na$treat.f=="1")])
pct2 <- sum(dat.na$d.vote[which(dat.na$treat.f=="3")])/length(dat.na$d.vote[which(dat.na$treat.f=="3")]) - sum(dat.na$d.vote[which(dat.na$treat.f=="1")])/length(dat.na$d.vote[which(dat.na$treat.f=="1")])
pct3 <- sum(dat.na$d.vote[which(dat.na$treat.f=="4")])/length(dat.na$d.vote[which(dat.na$treat.f=="4")]) - sum(dat.na$d.vote[which(dat.na$treat.f=="1")])/length(dat.na$d.vote[which(dat.na$treat.f=="1")])
pct4 <- sum(dat.na$d.vote[which(dat.na$treat.f=="5")])/length(dat.na$d.vote[which(dat.na$treat.f=="5")]) - sum(dat.na$d.vote[which(dat.na$treat.f=="1")])/length(dat.na$d.vote[which(dat.na$treat.f=="1")])

df <- data.frame(Support=rbind(pct1, pct2, pct3, pct4), Treatment=factor(c(2,3,4,5), labels=( c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate") ) ), ci.lo = ci.lims[,2], ci.hi = ci.lims[,1])

ggplot(data=df, aes(x=Treatment, y=Support, ymin=ci.lo, ymax=ci.hi)) + geom_pointrange() + theme_bw() + ylab("Difference in % Support for Democrat vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-difference-support.pdf", units="in", width=5, height=5.5)


###############
# basic models 
###############

library(sandwich)
library(lmtest)
library(car)

limits <- aes(ymax = resp + se, ymin=resp - se)

### support for republican candidate
mR <- lm(r.vote ~ as.factor(treat.f), data=dat)
summary(mR)

### with heteroskedastic errors
coeftest(mR, vcovHC(mR))

### support for democratic candidate
mD <- lm(d.vote ~ as.factor(treat.f), data=dat)
summary(mD)

### with heteroskedastic errors
coeftest(mD, vcovHC(mD))


#########################
# graph for basic models
#########################
library(mvtnorm)

### predicted support for republican
dr <- rmvnorm(1000, coef(mR), vcovHC(mR))
pred1 <- dr %*% c(1,0,0,0,0)
pred2 <- dr %*% c(1,1,0,0,0)
pred3 <- dr %*% c(1,0,1,0,0)
pred4 <- dr %*% c(1,0,0,1,0)
pred5 <- dr %*% c(1,0,0,0,1)
tmp1 <- quantile(pred1, probs=c(.025, .5, .975))
tmp2 <- quantile(pred2, probs=c(.025, .5, .975))
tmp3 <- quantile(pred3, probs=c(.025, .5, .975))
tmp4 <- quantile(pred4, probs=c(.025, .5, .975))
tmp5 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4,tmp5),Treatment=factor(c(1,2,3,4,5), labels=c("Control", "Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("% Support for Republican Candidate") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-support-basic.pdf", units="in", width=5, height=5.5)


### difference in support vs. control
pred2 <- dr %*% c(0,1,0,0,0)
pred3 <- dr %*% c(0,0,1,0,0)
pred4 <- dr %*% c(0,0,0,1,0)
pred5 <- dr %*% c(0,0,0,0,1)
tmp1 <- quantile(pred2, probs=c(.025, .5, .975))
tmp2 <- quantile(pred3, probs=c(.025, .5, .975))
tmp3 <- quantile(pred4, probs=c(.025, .5, .975))
tmp4 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4),Treatment=factor(c(2,3,4,5), labels=c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("Difference in % Republican Support vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-difference-support-basic.pdf", units="in", width=5, height=5.5)

### predicted support for democrat
dr <- rmvnorm(1000, coef(mD), vcovHC(mD))
pred1 <- dr %*% c(1,0,0,0,0)
pred2 <- dr %*% c(1,1,0,0,0)
pred3 <- dr %*% c(1,0,1,0,0)
pred4 <- dr %*% c(1,0,0,1,0)
pred5 <- dr %*% c(1,0,0,0,1)
tmp1 <- quantile(pred1, probs=c(.025, .5, .975))
tmp2 <- quantile(pred2, probs=c(.025, .5, .975))
tmp3 <- quantile(pred3, probs=c(.025, .5, .975))
tmp4 <- quantile(pred4, probs=c(.025, .5, .975))
tmp5 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4,tmp5),Treatment=factor(c(1,2,3,4,5), labels=c("Control", "Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("% Support for Democratic Candidate") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-support-basic.pdf", units="in", width=5, height=5.5)


### difference in support vs. control
pred2 <- dr %*% c(0,1,0,0,0)
pred3 <- dr %*% c(0,0,1,0,0)
pred4 <- dr %*% c(0,0,0,1,0)
pred5 <- dr %*% c(0,0,0,0,1)
tmp1 <- quantile(pred2, probs=c(.025, .5, .975))
tmp2 <- quantile(pred3, probs=c(.025, .5, .975))
tmp3 <- quantile(pred4, probs=c(.025, .5, .975))
tmp4 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4),Treatment=factor(c(2,3,4,5), labels=c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("Difference in % Democratic Support vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-difference-support-basic.pdf", units="in", width=5, height=5.5)



####################################
# models in partisan subpopulations
####################################

### support for republican candidate among republicans
dat.R <- subset(dat, subset=Q5 <= 2)

mR.R <- lm(r.vote ~ as.factor(treat.f), data=dat.R)
summary(mR.R)

### with heteroskedastic errors
coeftest(mR.R, vcovHC(mR.R))

### support for democratic candidate among democrats
dat.D <- subset(dat, subset=Q5 >= 6)

mD.D <- lm(d.vote ~ as.factor(treat.f), data=dat.D)
summary(mD.D)

### with heteroskedastic errors
coeftest(mD.D, vcovHC(mD.D))


############################################
# graph for model in partisan subpopulation
############################################

### predicted support for republican
dr <- rmvnorm(1000, coef(mR.R), vcovHC(mR.R))
pred1 <- dr %*% c(1,0,0,0,0)
pred2 <- dr %*% c(1,1,0,0,0)
pred3 <- dr %*% c(1,0,1,0,0)
pred4 <- dr %*% c(1,0,0,1,0)
pred5 <- dr %*% c(1,0,0,0,1)
tmp1 <- quantile(pred1, probs=c(.025, .5, .975))
tmp2 <- quantile(pred2, probs=c(.025, .5, .975))
tmp3 <- quantile(pred3, probs=c(.025, .5, .975))
tmp4 <- quantile(pred4, probs=c(.025, .5, .975))
tmp5 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4,tmp5),Treatment=factor(c(1,2,3,4,5), labels=c("Control", "Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("% Support for Republican Candidate") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-only-support.pdf", units="in", width=5, height=5.5)


### difference in support vs. control
pred2 <- dr %*% c(0,1,0,0,0)
pred3 <- dr %*% c(0,0,1,0,0)
pred4 <- dr %*% c(0,0,0,1,0)
pred5 <- dr %*% c(0,0,0,0,1)
tmp1 <- quantile(pred2, probs=c(.025, .5, .975))
tmp2 <- quantile(pred3, probs=c(.025, .5, .975))
tmp3 <- quantile(pred4, probs=c(.025, .5, .975))
tmp4 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4),Treatment=factor(c(2,3,4,5), labels=c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("Difference in % Republican Support vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-only-diff-support.pdf", units="in", width=5, height=5.5)


### predicted support for democrat
dr <- rmvnorm(1000, coef(mD.D), vcovHC(mD.D))
pred1 <- dr %*% c(1,0,0,0,0)
pred2 <- dr %*% c(1,1,0,0,0)
pred3 <- dr %*% c(1,0,1,0,0)
pred4 <- dr %*% c(1,0,0,1,0)
pred5 <- dr %*% c(1,0,0,0,1)
tmp1 <- quantile(pred1, probs=c(.025, .5, .975))
tmp2 <- quantile(pred2, probs=c(.025, .5, .975))
tmp3 <- quantile(pred3, probs=c(.025, .5, .975))
tmp4 <- quantile(pred4, probs=c(.025, .5, .975))
tmp5 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4,tmp5),Treatment=factor(c(1,2,3,4,5),  labels=c("Control", "Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("% Support for Democratic Candidate") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-only-support.pdf", units="in", width=5, height=5.5)


### difference in support vs. control
pred2 <- dr %*% c(0,1,0,0,0)
pred3 <- dr %*% c(0,0,1,0,0)
pred4 <- dr %*% c(0,0,0,1,0)
pred5 <- dr %*% c(0,0,0,0,1)
tmp1 <- quantile(pred2, probs=c(.025, .5, .975))
tmp2 <- quantile(pred3, probs=c(.025, .5, .975))
tmp3 <- quantile(pred4, probs=c(.025, .5, .975))
tmp4 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4),Treatment=factor(c(2,3,4,5), labels=c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("Difference in % Democratic Support vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-only-diff-support.pdf", units="in", width=5, height=5.5)


#########################
# models with covariates 
#########################

### support for republican candidate
mR.c <- lm(r.vote ~ as.factor(treat.f) + partyID + educ + black + native + asian + pacis + other + age + female, data=dat)
summary(mR.c)

### with heteroskedastic errors
coeftest(mR.c, vcovHC(mR.c))

### support for democratic candidate
mD.c <- lm(d.vote ~ as.factor(treat.f) + partyID + educ + black + native + asian + pacis + other + age + female, data=dat)
summary(mD.c)

### with heteroskedastic errors
coeftest(mD.c, vcovHC(mD.c))


##################################
# graph for model with covariates
##################################

### predicted support for republican
dr <- rmvnorm(1000, coef(mR.c), vcovHC(mR.c))

### difference in support vs. control
pred2 <- dr %*% c(0,1,0,0,0,0,0,0,0,0,0,0,0,0)
pred3 <- dr %*% c(0,0,1,0,0,0,0,0,0,0,0,0,0,0)
pred4 <- dr %*% c(0,0,0,1,0,0,0,0,0,0,0,0,0,0)
pred5 <- dr %*% c(0,0,0,0,1,0,0,0,0,0,0,0,0,0)
tmp1 <- quantile(pred2, probs=c(.025, .5, .975))
tmp2 <- quantile(pred3, probs=c(.025, .5, .975))
tmp3 <- quantile(pred4, probs=c(.025, .5, .975))
tmp4 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4),Treatment=factor(c(2,3,4,5), labels=c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("Difference in % Republican Support vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="republican-covariate-diff-support.pdf", units="in", width=5, height=5.5)


### predicted support for democrat
dr <- rmvnorm(1000, coef(mD.c), vcovHC(mD.c))

### difference in support vs. control
pred2 <- dr %*% c(0,1,0,0,0,0,0,0,0,0,0,0,0,0)
pred3 <- dr %*% c(0,0,1,0,0,0,0,0,0,0,0,0,0,0)
pred4 <- dr %*% c(0,0,0,1,0,0,0,0,0,0,0,0,0,0)
pred5 <- dr %*% c(0,0,0,0,1,0,0,0,0,0,0,0,0,0)
tmp1 <- quantile(pred2, probs=c(.025, .5, .975))
tmp2 <- quantile(pred3, probs=c(.025, .5, .975))
tmp3 <- quantile(pred4, probs=c(.025, .5, .975))
tmp4 <- quantile(pred5, probs=c(.025, .5, .975))

df <- data.frame(rbind(tmp1,tmp2,tmp3,tmp4),Treatment=factor(c(2,3,4,5), labels=c("Torture, D Candidate", "Torture, R Candidate", "Muslim Detention, D Candidate", "Muslim Detention, R Candidate")))

ggplot(data=df, aes(x=Treatment, y=X50., ymin=X2.5., ymax=X97.5.)) + geom_pointrange() + theme_bw() + ylab("Difference in % Democratic Support vs. Control") + theme(axis.text.x = element_text(angle = 15, hjust = 1))

ggsave(file="democratic-covariate-diff-support.pdf", units="in", width=5, height=5.5)


#############################################################################
#############################################################################
#############################################################################
#############################################################################
# begin nonpreregistered analysis
#############################################################################
#############################################################################
#############################################################################
#############################################################################


### joint f-tests (all treatments = 0)
### republican candidate, no covariates
mR.Ftest <- lht(mR, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mR))

### democratic candidate, no covariates
mD.Ftest <- lht(mD, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mD))

### make table of main results
mainresults <- stargazer(mR, mD, se = list(sqrt(diag(vcovHC(mR))), sqrt(diag(vcovHC(mD)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates. Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "tbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.Ftest[2,3], digits = 3)," (p$=$",round(mR.Ftest[2,4], digits = 3),")"), paste0(round(mD.Ftest[2,3], digits = 3)," (p$=$",round(mD.Ftest[2,4], digits = 3),")"))), label = "tab:main-regression-results")

write(x=mainresults, file="main-results.tex")



### joint f-tests (all treatments = 0)
### republican candidate, republicans only
mR.R.Ftest <- lht(mR.R, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mR.R))

### democratic candidate, democrats only
mD.D.Ftest <- lht(mD.D, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mD.D))

### make table of subpopulation-specific results
subpopresults <- stargazer(mR.R, mD.D, se = list(sqrt(diag(vcovHC(mR.R))), sqrt(diag(vcovHC(mD.D)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates in partisan sub-populations (i.e., support for the Republican candidate among Republican voters only, and support for the Democratic candidate among Democratic voters only). Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "tbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.R.Ftest[2,3], digits = 3)," (p$=$",round(mR.R.Ftest[2,4], digits = 3),")"), paste0(round(mD.D.Ftest[2,3], digits = 3)," (p$=$",round(mD.D.Ftest[2,4], digits = 3),")"))), label = "tab:subpop-regression-results")

write(x=subpopresults, file="subpop-results.tex")


### joint f-tests (all treatments = 0)
### republican candidate, with covariates
mR.c.Ftest <- lht(mR.c, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mR.c))

### democratic candidate, with covariates
mD.c.Ftest <- lht(mD.c, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mD.c))

### make table of main results with control variables
covariateresults <- stargazer(mR.c, mD.c, se = list(sqrt(diag(vcovHC(mR.c))), sqrt(diag(vcovHC(mD.c)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates, with control variables. Heteroskedasticity-consistent robust standard errors are presented in parentheses. Reported \\emph{F}-tests are for joint significance of treatment conditions, not including other covariates.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R", "Party ID", "Education", "Black", "Native American", "Asian", "Pacific Islander", "Other Race", "Age in years", "Female"), align = FALSE, no.space = TRUE, table.placement= "tbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.c.Ftest[2,3], digits = 3)," (p$=$",round(mR.c.Ftest[2,4], digits = 3),")"), paste0(round(mD.c.Ftest[2,3], digits = 3)," (p$=$",round(mD.c.Ftest[2,4], digits = 3),")"))), label = "tab:main-regression-w-covariates")

write(x=covariateresults, file="covariate-results.tex")



### likelihood of enacting policy
hist(dat$QC.10, breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), main = c("likelihood of $15 min wage, Democrat", "1 = very likely"))

# table of relationship between partisanship and likelihood assessment
library(xtable)
library(descr)
coarse.partisanship <- NA
coarse.partisanship[dat$Q5 <= 2] = "Republican"
coarse.partisanship[dat$Q5 > 2 & dat$Q5 < 6] = "Independent"
coarse.partisanship[dat$Q5 >= 6] = "Democrat"

coarse.likelihood.r <- NA
coarse.likelihood.r[dat$QT1.R.10 <=2] <- "likely (at least 50% chance)"
coarse.likelihood.r[dat$QT1.R.10 > 2] <- "unlikely (less than 50% chance)"
coarse.likelihood.r[dat$QT2.R.10 <=2] <- "likely (at least 50% chance)"
coarse.likelihood.r[dat$QT2.R.10 > 2] <- "unlikely (less than 50% chance)"

ct.r <- CrossTable(coarse.likelihood.r,coarse.partisanship, prop.c=T, prop.r=F, prop.t=F, prop.chisq=F, chisq=T, dnn=c("likelihood", "partisanship"))
print(xtable(ct.r, row.labels=F, format="SPSS", percent=T,
             caption = "\\textbf{Respondent's Assessment that Republican Candidate will Implement Human Rights Abuse.} Row shows
             the subject's self-reported belief that the candidate will implement torture or Muslim detention; column
             show s subject's partisanship. Cells show the number of subjects, with column percentages below.",
             label="tab:party-belief-r"), 
      file="crosstab-r.tex", include.rownames=F, caption.placement = "top",
      sanitize.text.function = function(x) sanitize(x, type="latex"))

coarse.likelihood.d <- NA
coarse.likelihood.d[dat$QT1.D.10 <=2] <- "likely (at least 50% chance)"
coarse.likelihood.d[dat$QT1.D.10 > 2] <- "unlikely (less than 50% chance)"
coarse.likelihood.d[dat$QT2.D.10 <=2] <- "likely (at least 50% chance)"
coarse.likelihood.d[dat$QT2.D.10 > 2] <- "unlikely (less than 50% chance)"

ct.d <- CrossTable(coarse.likelihood.d,coarse.partisanship, prop.c=T, prop.r=F, prop.t=F, prop.chisq=F, chisq=T, dnn=c("likelihood", "partisanship"))
print(xtable(ct.d, row.labels=F, format="SPSS", percent=T,
             caption = "\\textbf{Respondent's Assessment that Democratic Candidate will Implement Human Rights Abuse.} Row shows
             the subject's self-reported belief that the candidate will implement torture or Muslim detention; column
             show s subject's partisanship. Cells show the number of subjects, with column percentages below.",
             label="tab:party-belief-d"), 
      file="crosstab-d.tex", include.rownames=F, caption.placement = "top",
      sanitize.text.function = function(x) sanitize(x, type="latex"))



pdf(file="policy-likelihood.pdf", height=10, width=9)
par(mfrow=c(2,2))
hist(dat$QT1.R.10, breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), main = c("likelihood of torture, Republican", "1 = very likely"))
hist(dat$QT1.D.10, breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), main = c("likelihood of torture, Democrat", "1 = very likely"))
hist(dat$QT2.R.10, breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), main = c("likelihood of detention, Republican", "1 = very likely"))
hist(dat$QT2.D.10, breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), main = c("likelihood of detention, Democrat", "1 = very likely"))
dev.off()

ggplot(data=dat, aes(dat$QT1.R.10)) + geom_histogram(breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), col="black", fill="gray") + labs(x="Likelihood of torture", y="Frequency", title="likelihood of torture, Republican\n1 = very likely") + theme_bw()
ggsave(file="likelihood-torture-republican.pdf", units="in", width=5, height=5.5)

ggplot(data=dat, aes(dat$QT1.D.10)) + geom_histogram(breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), col="black", fill="gray") + labs(x="Likelihood of torture", y="Frequency", title="likelihood of torture, Democrat\n1 = very likely") + theme_bw()
ggsave(file="likelihood-torture-democratic.pdf", units="in", width=5, height=5.5)

ggplot(data=dat, aes(dat$QT2.R.10)) + geom_histogram(breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), col="black", fill="gray") + labs(x="Likelihood of internment", y="Frequency", title="likelihood of internment, Republican\n1 = very likely") + theme_bw()
ggsave(file="likelihood-internment-republican.pdf", units="in", width=5, height=5.5)

ggplot(data=dat, aes(dat$QT2.D.10)) + geom_histogram(breaks=c(0.5, 1.5, 2.5, 3.5, 4.5), col="black", fill="gray") + labs(x="Likelihood of internment", y="Frequency", title="likelihood of internment, Democrat\n1 = very likely") + theme_bw()
ggsave(file="likelihood-internment-democratic.pdf", units="in", width=5, height=5.5)


### subset: respondents who believed candidates would implement policies
dat$believe <- NA
dat$believe[which(dat$treat.f == 1)] <- 1
dat$believe[which(dat$treat.f == 2)] <- ifelse(dat$QT1.D.10 < 3, 1, 0)[which(dat$treat.f == 2)]
dat$believe[which(dat$treat.f == 3)] <- ifelse(dat$QT1.R.10 < 3, 1, 0)[which(dat$treat.f == 3)]
dat$believe[which(dat$treat.f == 4)] <- ifelse(dat$QT2.D.10 < 3, 1, 0)[which(dat$treat.f == 4)]
dat$believe[which(dat$treat.f == 5)] <- ifelse(dat$QT2.R.10 < 3, 1, 0)[which(dat$treat.f == 5)]

dat.b <- subset(dat, subset=(dat$believe==1))

### support for republican candidate
mRb <- lm(r.vote ~ as.factor(treat.f), data=dat.b)
summary(mRb)

### with heteroskedastic errors
coeftest(mRb, vcovHC(mRb))

### support for democratic candidate
mDb <- lm(d.vote ~ as.factor(treat.f), data=dat.b)
summary(mDb)

### with heteroskedastic errors
coeftest(mDb, vcovHC(mDb))

### joint f-test that all treatments=0
mRb.Ftest <- lht(mRb, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mRb))
mDb.Ftest <- lht(mDb, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mDb))

### make table of results among those who believe policies will be enacted
believerresults <- stargazer(mRb, mDb, se = list(sqrt(diag(vcovHC(mRb))), sqrt(diag(vcovHC(mDb)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for support for the Republican and Democratic candidates among those who believe there is at least a 50\\% chance the candidate will enact the proposed policy. Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "tbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mRb.Ftest[2,3], digits = 3)," (p$=$",round(mRb.Ftest[2,4], digits = 3),")"), paste0(round(mDb.Ftest[2,3], digits = 3)," (p$=$",round(mDb.Ftest[2,4], digits = 3),")"))), label = "tab:believer-regression-results")

write(x=believerresults, file="believer-results.tex")


# Bayesian Model Averaging models
require(BMA)
require(stringr)

dat.bic <- na.omit( subset(dat, select=c(treat.f, r.vote, d.vote)) )

# include or exclude ALL treatment variables (the default, but probably not
# the best idea)
mR.bic <- bic.glm(r.vote ~ as.factor(treat.f), data=dat.bic, glm.family="gaussian")
summary(mR.bic)

mD.bic <- bic.glm(d.vote ~ as.factor(treat.f), data=dat.bic, glm.family="gaussian")
summary(mD.bic)



# include or exclude ANY treatment variable individually
dat.bic$treat.2 <- as.numeric(dat.bic$treat.f==2)
dat.bic$treat.3 <- as.numeric(dat.bic$treat.f==3)
dat.bic$treat.4 <- as.numeric(dat.bic$treat.f==4)
dat.bic$treat.5 <- as.numeric(dat.bic$treat.f==5)

mR.bic <- bic.glm(r.vote ~ treat.2 + treat.3 + treat.4 + treat.5, data=dat.bic, glm.family="gaussian")
summary(mR.bic)

### make table of BMA estimates
### make table header
row_names <- c("Intercept (Baseline)", "Torture, D", "Torture, R", "Muslim Detention, D", "Muslim Detention, R", "", "Number of Variables", "BIC", "Posterior probability")
table <- c("\\begin{table}[H]",  
           "\\centering",
           "\\caption{\\textbf{BMA Estimates, Support for Republican.} Estimates are calculated via Bayesian Model Averaging, with the treatments included as separate dummy variables.} ",
           "\\begin{tabular}{@{\\extracolsep{5pt}}lccccc} ",
           "\\\\[-1.8ex]\\hline", 
           "\\hline \\\\[-1.8ex]", 
           "& \\multicolumn{5}{c}{Support for Republican} \\\\",
           "\\\\[-1.8ex]",
           "Variable & Pr$(\\beta \\neq 0)$ & EV & Std. Dev. & Model 1 & Model 2 \\\\ ",
           "\\hline \\\\[-1.8ex]")

### add values to table
for(i in 1:length(row_names)){
  tmp <- paste0(" ", row_names[i], " & ", paste(summary(mR.bic)[i,], collapse=" & "), " \\\\ ")
  table <- c(table, tmp)
}

### end table
table <- c(table, "\\hline \\hline \\\\", "\\end{tabular} ", "\\label{tab:republican-support-bma}", "\\end{table}")
write(x=table, file="republican-support-bma.tex")



mD.bic <- bic.glm(d.vote ~ treat.2 + treat.3 + treat.4 + treat.5, data=dat.bic, glm.family="gaussian")
summary(mD.bic)

### make table of BMA estimates
### make table header
row_names <- c("Intercept (Baseline)", "Torture, D", "Torture, R", "Muslim Detention, D", "Muslim Detention, R", "", "Number of Variables", "BIC", "Posterior probability")
table <- c("\\begin{sidewaystable}[htbp!]",  
           "\\centering",
           "\\caption{\\textbf{BMA Estimates, Support for Democrat.} Estimates are calculated via Bayesian Model Averaging, with the treatments included as separate dummy variables.} ",
           "\\begin{tabular}{@{\\extracolsep{5pt}}lcccccc} ",
           "\\\\[-1.8ex]\\hline", 
           "\\hline \\\\[-1.8ex]", 
           "& \\multicolumn{5}{c}{Support for Democrat} \\\\",
           "\\\\[-1.8ex]",
           "Variable & Pr$(\\beta \\neq 0)$ & EV & Std. Dev. & Model 1 & Model 2 & Model 3\\\\ ",
           "\\hline \\\\[-1.8ex]")

### add values to table
for(i in 1:length(row_names)){
  tmp <- paste0(" ", row_names[i], " & ", paste(summary(mD.bic)[i,], collapse=" & "), " \\\\ ")
  table <- c(table, tmp)
}

### end table
table <- c(table, "\\hline \\hline \\\\", "\\end{tabular} ", "\\label{tab:democratic-support-bma}", "\\end{sidewaystable}")
write(x=table, file="democratic-support-bma.tex")


###
# duration / attentiveness analysis
###

boxplot(dat$Duration..in.seconds.)
plot(density(dat$Duration..in.seconds.))
summary(dat$Duration..in.seconds.)
min(dat$Duration..in.seconds.)

sum(dat$Duration..in.seconds. < 120) / sum(dat$Duration..in.seconds > -1)
sum(dat$Duration..in.seconds. < 180) / sum(dat$Duration..in.seconds > -1)

hist(subset(dat, Duration..in.seconds. < 1000 )$Duration..in.seconds.)

dat.att <- subset(dat, Duration..in.seconds. >= 120)

### support for republican candidate
mR.att <- lm(r.vote ~ as.factor(treat.f), data=dat.att)
summary(mR.att)

### with heteroskedastic errors
coeftest(mR.att, vcovHC(mR.att))

### support for democratic candidate
mD.att <- lm(d.vote ~ as.factor(treat.f), data=dat.att)
summary(mD.att)

### with heteroskedastic errors
coeftest(mD.att, vcovHC(mD.att))

### joint f-tests (all treatments = 0)
### republican candidate, no covariates
mR.att.Ftest <- lht(mR.att, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mR.att))

### democratic candidate, no covariates
mD.att.Ftest <- lht(mD.att, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mD.att))

### make table of results for attentive subpopulation

stargazer(mR.att, mD.att, type="text", se = list(sqrt(diag(vcovHC(mR.att))), sqrt(diag(vcovHC(mD.att)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates, only respondents who spent at least 120 seconds completing the survey. Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "htbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.att.Ftest[2,3], digits = 3)," (p$=$",round(mR.att.Ftest[2,4], digits = 3),")"), paste0(round(mD.att.Ftest[2,3], digits = 3)," (p$=$",round(mD.att.Ftest[2,4], digits = 3),")"))), label = "tab:attentive-regression-results")

mainresults <- stargazer(mR.att, mD.att, se = list(sqrt(diag(vcovHC(mR.att))), sqrt(diag(vcovHC(mD.att)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates, only respondents who spent at least 120 seconds completing the survey. Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "htbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.att.Ftest[2,3], digits = 3)," (p$=$",round(mR.att.Ftest[2,4], digits = 3),")"), paste0(round(mD.att.Ftest[2,3], digits = 3)," (p$=$",round(mD.att.Ftest[2,4], digits = 3),")"))), label = "tab:attentive-regression-results")

write(x=mainresults, file="attentive-results.tex")



dat.v.att <- subset(dat, Duration..in.seconds. >= 180)

### support for republican candidate
mR.v.att <- lm(r.vote ~ as.factor(treat.f), data=dat.v.att)
summary(mR.v.att)

### with heteroskedastic errors
coeftest(mR.v.att, vcovHC(mR.v.att))

### support for democratic candidate
mD.v.att <- lm(d.vote ~ as.factor(treat.f), data=dat.v.att)
summary(mD.v.att)

### with heteroskedastic errors
coeftest(mD.v.att, vcovHC(mD.v.att))

### joint f-tests (all treatments = 0)
### republican candidate, no covariates
mR.v.att.Ftest <- lht(mR.v.att, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mR.v.att))

### democratic candidate, no covariates
mD.v.att.Ftest <- lht(mD.v.att, c("as.factor(treat.f)2 = 0", "as.factor(treat.f)3 = 0", "as.factor(treat.f)4 = 0", "as.factor(treat.f)5 = 0"), vcov=vcovHC(mD.v.att))

### make table of results for attentive subpopulation

stargazer(mR.v.att, mD.v.att, type="text", se = list(sqrt(diag(vcovHC(mR.v.att))), sqrt(diag(vcovHC(mD.v.att)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates, only respondents who spent at least 180 seconds completing the survey. Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "htbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.v.att.Ftest[2,3], digits = 3)," (p$=$",round(mR.v.att.Ftest[2,4], digits = 3),")"), paste0(round(mD.v.att.Ftest[2,3], digits = 3)," (p$=$",round(mD.v.att.Ftest[2,4], digits = 3),")"))), label = "tab:attentive-regression-results-two")

mainresults <- stargazer(mR.v.att, mD.v.att, se = list(sqrt(diag(vcovHC(mR.v.att))), sqrt(diag(vcovHC(mD.v.att)))), title = "\\textbf{OLS / LPM Model.} Regression coefficient estimates for model of support (binary) for the Republican and Democratic candidates, only respondents who spent at least 180 seconds completing the survey. Heteroskedasticity-consistent robust standard errors are presented in parentheses.", dep.var.caption = "", dep.var.labels.include = FALSE, column.labels = c("Support for Republican", "Support for Democrat"), covariate.labels = c("Intercept (Baseline)", "Torture, D", "Torture, R","Muslim Detention, D", "Muslim Detention, R"), align = FALSE, no.space = TRUE, table.placement= "htbp",  header = FALSE, intercept.bottom = FALSE, keep.stat = c("n","rsq"), model.names = FALSE, add.lines = list(c("F Statistic", paste0(round(mR.v.att.Ftest[2,3], digits = 3)," (p$=$",round(mR.v.att.Ftest[2,4], digits = 3),")"), paste0(round(mD.v.att.Ftest[2,3], digits = 3)," (p$=$",round(mD.v.att.Ftest[2,4], digits = 3),")"))), label = "tab:attentive-regression-results-two")

write(x=mainresults, file="attentive-results-2.tex")





######
# exploratory interaction models
# spoiler: there's nothing here of interest
######

### support for republican candidate
mR.c.int <- lm(r.vote ~ as.factor(treat.f)*female + partyID + educ + black + native + asian + pacis + other + age, data=dat)
summary(mR.c.int)

### with heteroskedastic errors
coeftest(mR.c.int, vcovHC(mR.c.int))

### support for democratic candidate
mD.c.int <- lm(d.vote ~ as.factor(treat.f)*female + partyID + educ + black + native + asian + pacis + other + age, data=dat)
summary(mD.c.int)

### with heteroskedastic errors
coeftest(mD.c.int, vcovHC(mD.c.int))




### support for republican candidate
mR.c.int <- lm(r.vote ~ as.factor(treat.f)*age + partyID + educ + black + native + asian + pacis + other + female, data=dat)
summary(mR.c.int)

### with heteroskedastic errors
coeftest(mR.c.int, vcovHC(mR.c.int))

### support for democratic candidate
mD.c.int <- lm(d.vote ~ as.factor(treat.f)*age + partyID + educ + black + native + asian + pacis + other + female, data=dat)
summary(mD.c.int)

### with heteroskedastic errors
coeftest(mD.c.int, vcovHC(mD.c.int))


##############################
# create descriptive tables
##############################

dat.sum <- subset(dat, select=c("partyID", "educ", "black", "native", "asian", "pacis", "other", "age", "female"))

dat.sum$republican <- coarse.partisanship == "Republican"
dat.sum$democrat <- coarse.partisanship == "Democrat"
dat.sum$independent <- coarse.partisanship == "Independent"

stargazer(dat.sum, type="text", median=TRUE,
                        covariate.labels = c("Party ID (7-point)", "Education", "Black", "Native American", "Asian", 
                                             "Pacific Islander", "Other Race", "Age", "Female", "Republican", "Democrat",
                                             "Independent"))

summarytab <- stargazer(dat.sum, median=TRUE,
                        covariate.labels = c("Party ID (7-point)", "Education", "Black", "Native American", "Asian", 
                                             "Pacific Islander", "Other Race", "Age", "Female", "Republican", "Democrat",
                                             "Independent"),
                        title = "\\textbf{Summary Statistics.} Summary information about demographic covariates.",
                        align = FALSE, no.space = TRUE, table.placement= "htbp", header=FALSE,
                        label = "tab:summary-tab", float.env="sidewaystable")

write(x=summarytab, file="summary-tab.tex")


library(xtable)

dat$treat.lab <- factor(dat$block, levels = c("Control", "T1D", "T1R", "T2D", "T2R"), 
                                     labels=c("Control", "Torture (D)", "Torture (R)", "Detain (D)", "Detain (R)"))

dat$vote.f <- factor(dat$vote, levels=c(1,2,3), labels = c("vote Republican", "vote Democratic", "Abstain"))

tab <- crosstab(dat$vote.f, dat$treat.lab,
           prop.r=F, prop.c=F, prop.t=F, expected=F, prop.chisq=F, plot=F,
           chisq=T, dnn=c(" ", "treatment condition"))

tab

tab.chisq <- chisq.test(table(dat$vote.f, dat$block))

print(xtable(tab, caption = paste("\\textbf{Summary of Experimental Results.} Rows indicate subject vote choices, while 
                                  columns indicate treatment conditions (the letter in parentheses indicates the party 
                                  of the candidate whose platform has been modified. Cell counts indicate the number of 
                                  subjects. $\\chi^2=", round(tab.chisq$statistic,3), "$ ($p = ", 
                                  round(tab.chisq$p.value, 3), "$). \\label{tab:results-sum}", sep="")),
      include.rownames=F, include.colnames=T, caption.placement="top",
      file="vote-treatment-table.tex")



tab <- crosstab(dat$vote.f, coarse.partisanship,
           prop.r=F, prop.c=F, prop.t=F, expected=F, prop.chisq=F, plot=F,
           chisq=T, dnn=c(" ", "partisanship"))

tab

tab.chisq <- chisq.test(table(dat$vote.f, coarse.partisanship))

if(tab.chisq$p.value >= 0.001){

  print(xtable(tab, caption = paste("\\textbf{Voting by Self-Reported Partisanship.} Rows indicate subject vote choices, 
                                    while columns indicate subject partisanship. Cell counts indicate the number of 
                                    subjects. $\\chi^2=", round(tab.chisq$statistic,3), "$ ($p = ", round(tab.chisq$p.value, 3),
                                    "$). \\label{tab:partisan-sum}", sep="")),
        include.rownames=F, include.colnames=T, caption.placement="top",
        file="vote-party-table.tex")
  
}else{
  
  print(xtable(tab, caption = paste("\\textbf{Voting by Self-Reported Partisanship.} Rows indicate subject vote choices, 
                                    while columns indicate subject partisanship. Cell counts indicate the number of 
                                    subjects. $\\chi^2=", round(tab.chisq$statistic,3), "$ ($p < 0.001$). 
                                    \\label{tab:partisan-sum}", sep="")),
        include.rownames=F, include.colnames=T, caption.placement="top",
        file="vote-party-table.tex")
  
}


dat$female.lab <- factor(dat$female, levels=c(0,1), labels=c("male"," female"))
crosstab(dat$vote.f, dat$female.lab,
                prop.r=F, prop.c=F, prop.t=F, expected=F, prop.chisq=F, plot=F,
                chisq=T, dnn=c("vote choice", "gender"))

dat$black.lab <- factor(dat$black, levels=c(0,1), labels=c("not black", "black"))
crosstab(dat$vote.f, dat$black.lab,
                prop.r=F, prop.c=F, prop.t=F, expected=F, prop.chisq=F, plot=F,
                chisq=T, dnn=c("vote choice", "race"))


dat$asian.lab <- factor(dat$asian, levels=c(0,1), labels=c("not asian", "asian"))
crosstab(dat$vote.f, dat$asian.lab,
                prop.r=F, prop.c=F, prop.t=F, expected=F, prop.chisq=F, plot=F,
                chisq=T, dnn=c("vote choice", "race"))



###############################
# balance checking
###############################

###
# gender balance
###

unique(dat$female)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$female, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Control")
axis(side=1, at=c(0,1), labels=c("male", "female"))
box()

hist( subset(dat, dat$block=="T1R")$female, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=c(0,1), labels=c("male", "female"))
box()

hist( subset(dat, dat$block=="T1D")$female, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=c(0,1), labels=c("male", "female"))
box()

hist( subset(dat, dat$block=="T2R")$female, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=c(0,1), labels=c("male", "female"))
box()

hist( subset(dat, dat$block=="T2D")$female, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=c(0,1), labels=c("male", "female"))
box()

prop.test(table(dat$block, dat$female))


###
# party ID
###

unique(dat$partyID)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$partyID, breaks=seq(0.5, 7.5, 1), 
      xaxt = "n", main = "Control")
axis(side=1, at=seq(1,7,1))
box()

hist( subset(dat, dat$block=="T1R")$partyID, breaks=seq(0.5, 7.5, 1), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=seq(1,7,1))
box()

hist( subset(dat, dat$block=="T1D")$partyID, breaks=seq(0.5, 7.5, 1), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=seq(1,7,1))
box()

hist( subset(dat, dat$block=="T2R")$partyID, breaks=seq(0.5, 7.5, 1), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=seq(1,7,1))
box()

hist( subset(dat, dat$block=="T2D")$partyID, breaks=seq(0.5, 7.5, 1), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=seq(1,7,1))
box()

summary(lm(partyID ~ block, data=dat))
chisq.test(table(dat$partyID, dat$block))


###
# education
###

unique(dat$educ)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$educ, breaks=seq(0.5, 8.5, 1), 
      xaxt = "n", main = "Control")
axis(side=1, at=seq(1,8,1))
box()

hist( subset(dat, dat$block=="T1R")$educ, breaks=seq(0.5, 8.5, 1), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=seq(1,8,1))
box()

hist( subset(dat, dat$block=="T1D")$educ, breaks=seq(0.5, 8.5, 1), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=seq(1,8,1))
box()

hist( subset(dat, dat$block=="T2R")$educ, breaks=seq(0.5, 8.5, 1), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=seq(1,8,1))
box()

hist( subset(dat, dat$block=="T2D")$educ, breaks=seq(0.5, 8.5, 1), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=seq(1,8,1))
box()

summary(lm(educ ~ block, data=dat))
chisq.test(table(dat$educ, dat$block), simulate.p.value=T, B=10000)

###
# black
###

unique(dat$black)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$black, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Control")
axis(side=1, at=c(0,1), labels=c("not black", "black"))
box()

hist( subset(dat, dat$block=="T1R")$black, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=c(0,1), labels=c("not black", "black"))
box()

hist( subset(dat, dat$block=="T1D")$black, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=c(0,1), labels=c("not black", "black"))
box()

hist( subset(dat, dat$block=="T2R")$black, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=c(0,1), labels=c("not black", "black"))
box()

hist( subset(dat, dat$block=="T2D")$black, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=c(0,1), labels=c("not black", "black"))
box()

prop.test(table(dat$block, dat$black))


###
# native
###

unique(dat$native)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$native, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Control")
axis(side=1, at=c(0,1), labels=c("not native", "native"))
box()

hist( subset(dat, dat$block=="T1R")$native, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=c(0,1), labels=c("not native", "native"))
box()

hist( subset(dat, dat$block=="T1D")$native, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=c(0,1), labels=c("not native", "native"))
box()

hist( subset(dat, dat$block=="T2R")$native, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=c(0,1), labels=c("not native", "native"))
box()

hist( subset(dat, dat$block=="T2D")$native, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=c(0,1), labels=c("not native", "native"))
box()

chisq.test(table(dat$block, dat$native), simulate.p.value=TRUE, B=10000)

###
# asian
###

unique(dat$asian)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$asian, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Control")
axis(side=1, at=c(0,1), labels=c("not asian", "asian"))
box()

hist( subset(dat, dat$block=="T1R")$asian, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=c(0,1), labels=c("not asian", "asian"))
box()

hist( subset(dat, dat$block=="T1D")$asian, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=c(0,1), labels=c("not asian", "asian"))
box()

hist( subset(dat, dat$block=="T2R")$asian, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=c(0,1), labels=c("not asian", "asian"))
box()

hist( subset(dat, dat$block=="T2D")$asian, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=c(0,1), labels=c("not asian", "asian"))
box()

chisq.test(table(dat$block, dat$asian), simulate.p.value=TRUE, B=10000)


###
# Pacific Islander
###

unique(dat$pacis)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$pacis, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Control")
axis(side=1, at=c(0,1), labels=c("not pacis", "pacis"))
box()

hist( subset(dat, dat$block=="T1R")$pacis, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=c(0,1), labels=c("not pacis", "pacis"))
box()

hist( subset(dat, dat$block=="T1D")$pacis, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=c(0,1), labels=c("not pacis", "pacis"))
box()

hist( subset(dat, dat$block=="T2R")$pacis, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=c(0,1), labels=c("not pacis", "pacis"))
box()

hist( subset(dat, dat$block=="T2D")$pacis, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=c(0,1), labels=c("not pacis", "pacis"))
box()

chisq.test(table(dat$block, dat$pacis), simulate.p.value=TRUE, B=10000)


###
# Other Race
###

unique(dat$other)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$other, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Control")
axis(side=1, at=c(0,1), labels=c("not other", "other"))
box()

hist( subset(dat, dat$block=="T1R")$other, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (R)")
axis(side=1, at=c(0,1), labels=c("not other", "other"))
box()

hist( subset(dat, dat$block=="T1D")$other, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Torture (D)")
axis(side=1, at=c(0,1), labels=c("not other", "other"))
box()

hist( subset(dat, dat$block=="T2R")$other, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (R)")
axis(side=1, at=c(0,1), labels=c("not other", "other"))
box()

hist( subset(dat, dat$block=="T2D")$other, breaks=c(-0.5, 0.5, 1.5), 
      xaxt = "n", main = "Detain (D)")
axis(side=1, at=c(0,1), labels=c("not other", "other"))
box()

chisq.test(table(dat$block, dat$other), simulate.p.value=TRUE, B=10000)


###
# age
###

unique(dat$age)
summary(dat$age)

par(mfrow=c(3,2))
hist( subset(dat, dat$block=="Control")$age, breaks=seq(18, 90, 6),
      main = "Control")
box()

hist( subset(dat, dat$block=="T1R")$age, breaks=seq(18, 90, 6),
      main = "Torture (R)")
box()

hist( subset(dat, dat$block=="T1D")$age, breaks=seq(18, 90, 6),
      main = "Torture (D)")
box()

hist( subset(dat, dat$block=="T2R")$age, breaks=seq(18, 90, 6),
      main = "Detain (R)")
box()

hist( subset(dat, dat$block=="T2D")$age, breaks=seq(18, 90, 6),
      main = "Detain (D)")
box()

summary(lm(age ~ block, data=dat))

